| Title: | Item Response Theory Demo Collection |
|---|---|
| Description: | Includes a collection of shiny applications to demonstrate or to explore fundamental item response theory (IRT) concepts such as estimation, scoring, and multidimensional IRT models. |
| Authors: | Metin Bulus [aut,cre] Wes Bonifay [aut,cre] |
| Maintainer: | Metin Bulus <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.4 |
| Built: | 2026-05-29 09:57:43 UTC |
| Source: | https://github.com/metinbulus/irtdemo |
Includes a collection of shiny applications to demonstrate or to explore fundamental item response theory (IRT) concepts such as estimation, scoring, and multidimensional IRT models.
irtDemo(text)irtDemo(text)
text |
argument in quotes referring to the name of shiny application. See details for the list of applications. |
text argument can be one of the followings:
“mle” for Maximum Likelihood Estimation
“est2pl” for Estimation in 2PL Model
“est3pl” for Estimation in 3PL Model
“eapmap” for Expected a Posteriori (EAP) and Maximum a Posteriori (MAP) Estimation
“dich” for Dichotomous IRT Models
“gpcm” for Generalized Partial Credit and Partial Credit Models
“grm” for Graded Response Model
“grsm” for Generalized Rating Scale and Rating Scale Models
“nrm” for Nominal Response Model
“mirt” for Multidimensional Item Response Theory Model
Metin Bulus [email protected] and Wes Bonifay [email protected]
## Not run: irtDemo("eapmap") irtDemo("mirt") ## End(Not run)## Not run: irtDemo("eapmap") irtDemo("mirt") ## End(Not run)