Welcome to ClientVPS Mirrors

Help for package irtDemo
Type: Package
Title: Item Response Theory Demo Collection
Version: 0.1.5
Date: 2025-04-21
Maintainer: Metin Bulus <bulusmetin@gmail.com>
Description: Includes a collection of shiny applications to demonstrate or to explore fundamental item response theory (IRT) concepts such as estimation, scoring, and multidimensional IRT models.
Depends: R (≥ 3.2.4)
Imports: shiny (≥ 0.13.2), fGarch (≥ 3010.82)
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
NeedsCompilation: no
Packaged: 2025-04-22 04:01:39 UTC; LENOVO
Author: Metin Bulus [aut, cre], Wes Bonifay [aut, ctb]
Repository: CRAN
Date/Publication: 2025-04-22 04:20:02 UTC

Item Response Theory Demo Collection

Description

Includes a collection of shiny applications to demonstrate or to explore fundamental item response theory (IRT) concepts such as estimation, scoring, and multidimensional IRT models.

Usage

  irtDemo(text)

Arguments

text

argument in quotes referring to the name of shiny application. See details for the list of applications.

Details

text argument can be one of the followings:

Author(s)

Metin Bulus bulusmetin@gmail.com and Wes Bonifay bonifayw@missouri.edu

References

Bulus, M., & Bonifay, W. (2022). irtDemo R Package: Pedagogical Interactive Web Applications for Estimation, Scoring, and Multi Dimensionality in Item Response Theory. Anadolu University Journal of Education Faculty, 6(1), 92-108. doi: 10.34056/aujef.913781

Examples

  ## Not run: 

    irtDemo("eapmap")
    irtDemo("mirt")
  
## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.